@@ -1,6 +1,6 @@
 """DFCX End to End Conversation Functions"""
 
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -65,9 +65,8 @@ class DialogflowConversation(scrapi_base.ScrapiBase):
         )
 
         logging.info(
-            f"create conversation with creds_path: \
-                {creds_path} | agent_id: {agent_id}",
-        )
+            "create conversation with creds_path: %s | agent_id: %s",
+            creds_path, agent_id)
 
         if agent_id or config["agent_path"]:
             self.agent_id = agent_id or config["agent_path"]
@@ -96,6 +95,7 @@ class DialogflowConversation(scrapi_base.ScrapiBase):
             4: "NO_MATCH",
             5: "NO_INPUT",
             6: "EVENT",
+            8: "KNOWLEDGE_CONNECTOR"
         }
 
         return match_type_map[match_type]
@@ -109,7 +109,7 @@ class DialogflowConversation(scrapi_base.ScrapiBase):
         invalid_pages = set(test_set.page_display_name[mask].to_list())
 
         if invalid_pages:
-            raise Exception(
+            raise UserWarning(
                 "The following Pages are invalid and missing Page "
                 f"IDs: \n{invalid_pages}\n\nPlease ensure that your Page "
                 "Display Names do not contain typos.\nFor Default Start Page "
@@ -325,8 +325,8 @@ class DialogflowConversation(scrapi_base.ScrapiBase):
             )
             threads[i].start()
 
-        for idx, _ in enumerate(threads):
-            threads[idx].join()
+        for _, thread in enumerate(threads):
+            thread.join()
 
         test_set_mapped["target_page"] = results["target_page"]
         test_set_mapped["match"] = results["match"]
