@@ -1,6 +1,6 @@
 """Entity Types Resource functions."""
 
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -293,16 +293,22 @@ class EntityTypes(ScrapiBase):
         return response
 
     def create_entity_type(
-        self, agent_id: str = None, obj: types.EntityType = None,
-        language_code: str = None, **kwargs
+        self,
+        agent_id: str = None,
+        display_name: str = None,
+        language_code: str = None,
+        obj: types.EntityType = None,
+        **kwargs
     ) -> types.EntityType:
         """Creates a single Entity Type object resource.
 
         Args:
           agent_id: the formatted CX Agent ID to create the object on
-          obj: The CX EntityType object in proper format.
+          display_name: Human readable display name for the EntityType
           language_code: Language code of the intents being uploaded. Ref:
             https://cloud.google.com/dialogflow/cx/docs/reference/language
+          obj: The CX EntityType object in proper format.
+            Refer to `builders.entity_types.EntityTypeBuilder` to build one.
 
         Returns:
           A copy of the Entity Type object created
@@ -312,14 +318,21 @@ class EntityTypes(ScrapiBase):
 
         # If entity_type_obj is given set entity_type to it
         if obj:
-            entity_type = obj
-            entity_type.name = ""
+            entity_type_obj = obj
+            entity_type_obj.name = ""
         else:
-            entity_type = types.entity_type.EntityType()
+            if not display_name:
+                raise ValueError(
+                    "At least display_name or obj should be specified."
+                )
+            entity_type_obj = types.EntityType(
+                display_name=display_name,
+                kind=1
+            )
 
-        # set optional arguments to entity type attributes
-        for key, value in kwargs.items():
-            setattr(entity_type, key, value)
+            # set optional arguments to entity type attributes
+            for key, value in kwargs.items():
+                setattr(entity_type_obj, key, value)
 
         client_options = self._set_region(agent_id)
         client = services.entity_types.EntityTypesClient(
@@ -329,7 +342,7 @@ class EntityTypes(ScrapiBase):
         request = types.entity_type.CreateEntityTypeRequest()
 
         request.parent = agent_id
-        request.entity_type = entity_type
+        request.entity_type = entity_type_obj
 
         if language_code:
             request.language_code = language_code
